@@ -1,7 +1,7 @@
 enumerateCycles <- function(model,rxnList,solver = SYBIL_SETTINGS("SOLVER") ){
-fva=lrFVA(model,rxnList,solver)
-ldet=fva[[2]]
-lp=ldet[ldet[,"llen"]>0,]
+fva=cfFVA(model,rxnList,solver)
+ldet=fva[[3]]
+lp=ldet[ldet[,"llen"]>0,,drop=FALSE]
 ulp=unique(lp[,c("lp","llen")])
 return (ulp)
 }
\ No newline at end of file
